@@ -156,6 +156,9 @@ class Emitter(object):
         self.column = 0
         self.whitespace = True
         self.indention = True
+        self.compact_seq_seq = True  # dash after dash
+        self.compact_seq_map = True  # key after dash
+        # self.compact_ms = False   # dash after key, only when excplicit key with ?
         self.no_newline = None  # type: Optional[bool]  # set if directly after `- `
 
         # Whether the document requires an explicit document indicator
@@ -399,19 +402,28 @@ class Emitter(object):
         if isinstance(self.event, AliasEvent):
             self.expect_alias()
         elif isinstance(self.event, (ScalarEvent, CollectionStartEvent)):
-            self.process_anchor(u'&')
+            if (
+                self.process_anchor(u'&')
+                and isinstance(self.event, ScalarEvent)
+                and self.sequence_context
+            ):
+                self.sequence_context = False
             self.process_tag()
             if isinstance(self.event, ScalarEvent):
+                # nprint('@', self.indention, self.no_newline, self.column)
                 self.expect_scalar()
             elif isinstance(self.event, SequenceStartEvent):
+                # nprint('@', self.indention, self.no_newline, self.column)
+                i2, n2 = self.indention, self.no_newline  # NOQA
                 if self.event.comment:
                     if self.event.flow_style is False and self.event.comment:
                         if self.write_post_comment(self.event):
                             self.indention = False
                             self.no_newline = True
                     if self.write_pre_comment(self.event):
-                        self.indention = False
-                        self.no_newline = True
+                        pass
+                        self.indention = i2
+                        self.no_newline = not self.indention
                 if (
                     self.flow_level
                     or self.canonical
@@ -593,7 +605,12 @@ class Emitter(object):
 
     def expect_block_sequence(self):
         # type: () -> None
-        indentless = self.mapping_context and not self.indention
+        if self.mapping_context:
+            indentless = not self.indention
+        else:
+            indentless = False
+            if not self.compact_seq_seq and self.column != 0:
+                self.write_line_break()
         self.increase_indent(flow=False, sequence=True, indentless=indentless)
         self.state = self.expect_first_block_sequence_item
 
@@ -626,6 +643,8 @@ class Emitter(object):
 
     def expect_block_mapping(self):
         # type: () -> None
+        if not self.mapping_context and not (self.compact_seq_map or self.column == 0):
+            self.write_line_break()
         self.increase_indent(flow=False, sequence=False)
         self.state = self.expect_first_block_mapping_key
 
@@ -650,10 +669,15 @@ class Emitter(object):
                 if not isinstance(
                     self.event, (SequenceStartEvent, MappingStartEvent)
                 ):  # sequence keys
-                    if self.event.style == '?':
-                        self.write_indicator(u'?', True, indention=True)
+                    try:
+                        if self.event.style == '?':
+                            self.write_indicator(u'?', True, indention=True)
+                    except AttributeError:  # aliases have no style
+                        pass
                 self.states.append(self.expect_block_mapping_simple_value)
                 self.expect_node(mapping=True, simple_key=True)
+                if isinstance(self.event, AliasEvent):
+                    self.stream.write(u' ')
             else:
                 self.write_indicator(u'?', True, indention=True)
                 self.states.append(self.expect_block_mapping_value)
@@ -744,15 +768,16 @@ class Emitter(object):
     # Anchor, Tag, and Scalar processors.
 
     def process_anchor(self, indicator):
-        # type: (Any) -> None
+        # type: (Any) -> bool
         if self.event.anchor is None:
             self.prepared_anchor = None
-            return
+            return False
         if self.prepared_anchor is None:
             self.prepared_anchor = self.prepare_anchor(self.event.anchor)
         if self.prepared_anchor:
             self.write_indicator(indicator + self.prepared_anchor, True)
         self.prepared_anchor = None
+        return True
 
     def process_tag(self):
         # type: () -> None
@@ -832,6 +857,7 @@ class Emitter(object):
         # if self.analysis.multiline and split    \
         #         and (not self.style or self.style in '\'\"'):
         #     self.write_indent()
+        # nprint('xx', self.sequence_context, self.flow_level)
         if self.sequence_context and not self.flow_level:
             self.write_indent()
         if self.style == '"':
@@ -1011,6 +1037,8 @@ class Emitter(object):
                 if ch in u'?:':  # ToDo
                     if self.serializer.use_version == (1, 1):
                         flow_indicators = True
+                    elif len(scalar) == 1:  # single character
+                        flow_indicators = True
                     if followed_by_whitespace:
                         block_indicators = True
                 if ch == u'-' and followed_by_whitespace:
@@ -1448,9 +1476,12 @@ class Emitter(object):
                         data = data.encode(self.encoding)
                     self.stream.write(data)
                     if ch == u'\a':
-                        self.write_line_break()
-                        self.write_indent()
-                        end += 2  # \a and the space that is inserted on the fold
+                        if end < (len(text) - 1) and not text[end + 2].isspace():
+                            self.write_line_break()
+                            self.write_indent()
+                            end += 2  # \a and the space that is inserted on the fold
+                        else:
+                            raise EmitterError('unexcpected fold indicator \\a before space')
                     if ch is None:
                         self.write_line_break()
                     start = end
@@ -1486,9 +1517,10 @@ class Emitter(object):
                         else:
                             self.write_line_break(br)
                     if ch is not None:
-                        if _indent:
-                            self.stream.write(u' ' * _indent)
-                        elif not self.root_context or self.requested_indent:
+                        if self.root_context:
+                            idnx = self.indent if self.indent is not None else 0
+                            self.stream.write(u' ' * (_indent + idnx))
+                        else:
                             self.write_indent()
                     start = end
             else:
@@ -1573,11 +1605,11 @@ class Emitter(object):
                 breaks = ch in u'\n\x85\u2028\u2029'
             end += 1
 
-    def write_comment(self, comment):
-        # type: (Any) -> None
+    def write_comment(self, comment, pre=False):
+        # type: (Any, bool) -> None
         value = comment.value
-        # nprint('{:02d} {:02d} {!r}'.format(self.column, comment.start_mark.column, value))
-        if value[-1] == '\n':
+        # nprintf('{:02d} {:02d} {!r}'.format(self.column, comment.start_mark.column, value))
+        if not pre and value[-1] == '\n':
             value = value[:-1]
         try:
             # get original column position
@@ -1606,7 +1638,8 @@ class Emitter(object):
             self.stream.write(value)
         except TypeError:
             raise
-        self.write_line_break()
+        if not pre:
+            self.write_line_break()
 
     def write_pre_comment(self, event):
         # type: (Any) -> bool
@@ -1620,7 +1653,7 @@ class Emitter(object):
                     continue
                 if self.column != 0:
                     self.write_line_break()
-                self.write_comment(comment)
+                self.write_comment(comment, pre=True)
                 if isinstance(event, start_events):
                     comment.pre_done = True
         except TypeError:
